==> ejc-zjkjcost-impl-3.0.0-20220712.025208-37-sources.jar: com/ejianc/business/zjkjcost/reserve/bean/AllocateHistoryApproveEntity.java <==
package com.ejianc.business.zjkjcost.reserve.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 风险预留金-项目部人员风险金预留分配记录表孙子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_reserve_allocate_history_approve")
public class AllocateHistoryApproveEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="allocate_id")
    private Long allocateId; // 主表主键ID
    @TableField(value="personnel_id")
    private Long personnelId; // 人员ID
    @TableField(value="personnel_name")
    private String personnelName; // 人员名称
    @TableField(value="allocate_detail_id")
    private Long allocateDetailId; // 所属子表id
    @TableField(value="source_id")
    private Long sourceId; // 来源id
    @TableField(value="source_code")
    private Long sourceCode; // 来源编码


    public Long getSourceCode() {
        return sourceCode;
    }

    public void setSourceCode(Long sourceCode) {
        this.sourceCode = sourceCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getAllocateId() {
        return allocateId;
    }

    public void setAllocateId(Long allocateId) {
        this.allocateId = allocateId;
    }
    public Long getPersonnelId() {
        return personnelId;
    }

    public void setPersonnelId(Long personnelId) {
        this.personnelId = personnelId;
    }
    public String getPersonnelName() {
        return personnelName;
    }

    public void setPersonnelName(String personnelName) {
        this.personnelName = personnelName;
    }
    public Long getAllocateDetailId() {
        return allocateDetailId;
    }

    public void setAllocateDetailId(Long allocateDetailId) {
        this.allocateDetailId = allocateDetailId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }






}

==> ejc-zjkjcost-impl-3.0.0-20230519.072252-173-sources.jar: com/ejianc/business/zjkjcost/reserve/bean/AllocateHistoryApproveEntity.java <==
package com.ejianc.business.zjkjcost.reserve.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 风险预留金-项目部人员风险金预留分配记录表孙子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_reserve_allocate_history_approve")
public class AllocateHistoryApproveEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="allocate_id")
    private Long allocateId; // 主表主键ID
    @TableField(value="personnel_id")
    private Long personnelId; // 人员ID
    @TableField(value="personnel_name")
    private String personnelName; // 人员名称
    @TableField(value="allocate_detail_id")
    private Long allocateDetailId; // 所属子表id
    @TableField(value="source_id")
    private Long sourceId; // 来源id
    @TableField(value="source_code")
    private String sourceCode; // 来源编码
    @TableField(value="source_type")
    private Integer sourceType; //  来源类型 1-返还，2-转抵）

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public String getSourceCode() {
        return sourceCode;
    }

    public void setSourceCode(String sourceCode) {
        this.sourceCode = sourceCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getAllocateId() {
        return allocateId;
    }

    public void setAllocateId(Long allocateId) {
        this.allocateId = allocateId;
    }
    public Long getPersonnelId() {
        return personnelId;
    }

    public void setPersonnelId(Long personnelId) {
        this.personnelId = personnelId;
    }
    public String getPersonnelName() {
        return personnelName;
    }

    public void setPersonnelName(String personnelName) {
        this.personnelName = personnelName;
    }
    public Long getAllocateDetailId() {
        return allocateDetailId;
    }

    public void setAllocateDetailId(Long allocateDetailId) {
        this.allocateDetailId = allocateDetailId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }






}
